#[non_exhaustive]pub enum MemoryRange {
Rom(Range<usize>),
Ram(Range<usize>),
Interface1Rom,
PlusDRom,
DiscipleRom,
MultifaceRom,
SamRamRom(Range<usize>),
}Expand description
The memory range specifies which part of the emulated hardware the data should be loaded to.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Rom(Range<usize>)
Load into the main ROM. The address space starts from the top of the first ROM bank and extends towards the last ROM bank.
Ram(Range<usize>)
Load into the main RAM. The address space starts from the top of the first RAM bank and extends towards the last RAM bank.
Interface1Rom
Load into the Interface1 ROM.
PlusDRom
Load into the MGT +D ROM.
DiscipleRom
Load into the MGT DISCiPLE ROM.
MultifaceRom
Load into the Multiface ROM.
SamRamRom(Range<usize>)
Load into the SamRam ROM. The address space starts from the top of the first ROM bank and extends towards the last ROM bank.